summaryrefslogtreecommitdiffstats
path: root/src/corelib/text/qlocale_p.h
diff options
context:
space:
mode:
authorLars Knoll <lars.knoll@qt.io>2020-05-22 14:49:30 +0200
committerLars Knoll <lars.knoll@qt.io>2020-06-11 02:50:16 +0200
commitecacb3c62f94d2b671a252aa177264f41f6869ea (patch)
tree9595f19bdeda1009ccf07155d51c2eaff679fe54 /src/corelib/text/qlocale_p.h
parentce8c33e710a9003a1912ab09fc31417b50b7a4b5 (diff)
Port QLocale::quoteString from QStringRef to QStringView
Task-number: QTBUG-84319 Change-Id: I29726ebfda7a5f51a0a6ee29e905b0b904256c8d Reviewed-by: Edward Welbourne <edward.welbourne@qt.io> Reviewed-by: Thiago Macieira <thiago.macieira@intel.com>
Diffstat (limited to 'src/corelib/text/qlocale_p.h')
-rw-r--r--src/corelib/text/qlocale_p.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/corelib/text/qlocale_p.h b/src/corelib/text/qlocale_p.h
index 42d434eac4..751e254d53 100644
--- a/src/corelib/text/qlocale_p.h
+++ b/src/corelib/text/qlocale_p.h
@@ -116,8 +116,8 @@ public:
CurrencyToString, // QString in: qlonglong, qulonglong or double
Collation, // QString
UILanguages, // QStringList
- StringToStandardQuotation, // QString in: QStringRef to quote
- StringToAlternateQuotation, // QString in: QStringRef to quote
+ StringToStandardQuotation, // QString in: QStringView to quote
+ StringToAlternateQuotation, // QString in: QStringView to quote
ScriptId, // uint
ListToSeparatedString, // QString
LocaleChanged, // system locale changed
@@ -515,7 +515,7 @@ Q_STATIC_ASSERT(!ascii_isspace(uchar('\377')));
QT_END_NAMESPACE
-Q_DECLARE_METATYPE(QStringRef)
+Q_DECLARE_METATYPE(QStringView)
Q_DECLARE_METATYPE(QList<Qt::DayOfWeek>)
#ifndef QT_NO_SYSTEMLOCALE
Q_DECLARE_METATYPE(QSystemLocale::CurrencyToStringArgument)